@@ -239,7 +239,7 @@ class security_manager {
         }
     }
     
-    public function block_ip($ip_address, $reason = 'Manual block', $failed_attempts = 0, $indefinite = false, $skip_service_blocks = false) {
+    public function block_ip($ip_address, $reason = 'Manual block', $failed_attempts = 0, $permanent = false, $skip_service_blocks = false) {
         // Don't block whitelisted IPs
         if ($this->is_ip_whitelisted($ip_address)) {
             return false;
@@ -251,7 +251,7 @@ class security_manager {
         }
         
         // Store in local database
-        $unblock_time = $indefinite ? 0 : (time() + $this->block_duration); // 0 means indefinite/manual unblock only
+        $unblock_time = $permanent ? 0 : (time() + $this->block_duration); // 0 means permanent/manual unblock only
         $stmt = $this->db->prepare('INSERT OR REPLACE INTO blocked_ips (ip_address, block_time, unblock_time, reason, failed_attempts, manual_block) VALUES (:ip, :block_time, :unblock_time, :reason, :attempts, :manual)');
         $stmt->bindValue(':ip', $ip_address, SQLITE3_TEXT);
         $stmt->bindValue(':block_time', time(), SQLITE3_INTEGER);
@@ -276,9 +276,9 @@ class security_manager {
             try {
                 require_once('/docker/whp/web/libs/log_monitor_manager.php');
                 $log_monitor = new log_monitor_manager();
-                // Block on both SSH and FTP services
-                $log_monitor->block_service_ip('ssh', $ip_address, $reason, $failed_attempts);
-                $log_monitor->block_service_ip('ftp', $ip_address, $reason, $failed_attempts);
+                // Block on both SSH and FTP services with the same permanent flag
+                $log_monitor->block_service_ip('ssh', $ip_address, $reason, $failed_attempts, $permanent);
+                $log_monitor->block_service_ip('ftp', $ip_address, $reason, $failed_attempts, $permanent);
             } catch (Exception $e) {
                 error_log("Failed to block IP in SSH/FTP services: " . $e->getMessage());
                 // Continue even if service blocking fails
