@@ -79,10 +79,10 @@ if ($_SERVER['REQUEST_METHOD'] === 'POST') {
             case 'block_ip':
                 if (!empty($_POST['ip_address']) && filter_var($_POST['ip_address'], FILTER_VALIDATE_IP)) {
                     $reason = !empty($_POST['reason']) ? substr(trim($_POST['reason']), 0, 255) : 'Manual block';
-                    $indefinite = isset($_POST['indefinite']) && $_POST['indefinite'] == '1';
-                    $result = $SecManager->block_ip($_POST['ip_address'], $reason, 0, $indefinite, false);
+                    $permanent = isset($_POST['permanent']) && $_POST['permanent'] == '1';
+                    $result = $SecManager->block_ip($_POST['ip_address'], $reason, 0, $permanent, false);
                     if ($result) {
-                        $block_type = $indefinite ? 'indefinitely' : 'temporarily';
+                        $block_type = $permanent ? 'permanently' : 'temporarily';
                         $message = 'IP address blocked ' . $block_type . ': ' . htmlspecialchars($_POST['ip_address']);
                         $message_type = 'success';
                     } else {
@@ -240,7 +240,7 @@ foreach ($security_blocked_ips as $security_block) {
     foreach ($service_blocked_ips as &$service_block) {
         if ($service_block['ip_address'] === $security_block['ip_address']) {
             $found_in_service = true;
-            // If security manager block is newer or indefinite, update the display
+            // If security manager block is newer or permanent, update the display
             if ($security_block['block_time'] > $service_block['block_time'] || $security_block['unblock_time'] == 0) {
                 $service_block['reason'] = $security_block['reason'];
                 $service_block['blocking_service'] = 'security_manager';
@@ -600,9 +600,9 @@ $access_stats = $PermManager->get_system_access_stats(30);
                     </div>
                     <div class="mb-3">
                         <div class="form-check">
-                            <input class="form-check-input" type="checkbox" id="indefinite_block" name="indefinite" value="1">
-                            <label class="form-check-label" for="indefinite_block">
-                                Block indefinitely
+                            <input class="form-check-input" type="checkbox" id="permanent_block" name="permanent" value="1">
+                            <label class="form-check-label" for="permanent_block">
+                                Block permanently
                             </label>
                         </div>
                     </div>
@@ -845,10 +845,10 @@ if (!empty($service_blocked_ips)): ?>
                                 </td>
                                 <td>
                                     <?php 
-                                    // Check if this is an indefinite block
+                                    // Check if this is a permanent block
                                     if ($blocked['unblock_time'] == 0 || $blocked['unblock_time'] == 4102444799) {
-                                        // Indefinite block (0 or year 2099)
-                                        echo '<small class="text-danger"><strong>Indefinite</strong></small>';
+                                        // Permanent block (0 or year 2099)
+                                        echo '<small class="text-danger"><strong>Permanent</strong></small>';
                                     } else {
                                         $time_left = $blocked['unblock_time'] - time();
                                         if ($time_left <= 0) {
